#
# spec file for package meanwhile
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  libmeanwhile
%define sover   1
Name:           meanwhile
Version:        1.1.1
Release:        2.2
Summary:        IBM Sametime Community Client Library
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://github.com/obriencj/meanwhile
Source:         https://github.com/obriencj/meanwhile/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE meanwhile-use-libtommath.patch boo#1086826 sor.alexei@meowr.ru -- Use LibTomMath as an MPI instead of the bundled code.
Patch0:         meanwhile-use-libtommath.patch
# PATCH-FIX-OPENSUSE meanwhile-fix-warnings.patch -- Fix various warnings.
Patch1:         meanwhile-fix-warnings.patch
# PATCH-FIX-OPENSUSE meanwhile-fix-groupchat.patch pidgin#12637 -- Fix for group chat crashes with IBM Notes version 8.5.1 by Jonathan Rice.
Patch2:         meanwhile-fix-groupchat.patch
# PATCH-FIX-OPENSUSE meanwhile-fix-filetransfer.patch mikael.berthe@lilotux.net -- Fix file transfers with recent Sametime servers.
Patch3:         meanwhile-fix-filetransfer.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtommath-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0)

%description
A library to establish instant messaging connections to the IBM
Sametime IM server.

%package -n %{soname}%{sover}
Summary:        IBM Sametime Community Client Library
# libmeanwhile was last used in openSUSE 12.2.
Group:          System/Libraries
Obsoletes:      %{soname} < %{version}
Provides:       %{soname} = %{version}

%description -n %{soname}%{sover}
A library to establish instant messaging connections to the IBM
Sametime IM server.

%package devel
Summary:        IBM Sametime Community Client library
Group:          Development/Libraries/C and C++
Requires:       %{soname}%{sover} = %{version}
Requires:       pkgconfig(glib-2.0)

%description devel
A library to establish instant messaging connections to the IBM
Sametime IM server.

%package doc
Summary:        IBM Sametime Community Client library
Group:          Development/Libraries/C and C++

%description doc
A library to establish instant messaging connections to the IBM
Sametime IM server.

%prep
%autosetup -p1
touch configwrap && chmod a+x configwrap

%build
./autogen.sh
%configure \
  --disable-doxygen \
  --disable-mailme  \
  --disable-static
make %{?_smp_mflags} V=1

%install
%make_install \
  sampledir=%{_docdir}/%{name}/samples

chmod a-x %{buildroot}%{_docdir}/%{name}/samples/build
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{soname}%{sover} -p /sbin/ldconfig

%postun -n %{soname}%{sover} -p /sbin/ldconfig

%files -n %{soname}%{sover}
%license COPYING
%doc ChangeLog README
%{_libdir}/%{soname}.so.%{sover}*

%files devel
%{_includedir}/meanwhile/
%{_libdir}/%{soname}.so
%{_libdir}/pkgconfig/meanwhile.pc

%files doc
%dir %{_docdir}/%{name}/
%{_docdir}/%{name}/samples/

%changelog
* Fri Feb 23 2024 pgajdos@suse.com
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN
* Mon Feb 25 2019 sor.alexei@meowr.ru
- Update to version 1.1.1 (changes since 1.0.2):
  * Fix errant return in cipher.c.
  * Buddy list shows wrong status.
  * strict-prototypes warning fix.
  * Fixed glib headers compile issue
  * Fixed string crash bug in st_list.c
  * Fix Awareness status timestamps with recent Sametime clients.
  * Add a flag in status enum for mobile users.
- Rebase meanwhile-fix-warnings.patch.
- Remove meanwhile-1.0.2-add-status-flags.patch,
  meanwhile-glib-2.31.patch, meanwhile-status.diff,
  meanwhile-workaround-status-timestamp.patch.
* Thu Jul 12 2018 sor.alexei@meowr.ru
- Add meanwhile-1.0.2-add-status-flags.patch: Add flag in status
  enum for mobile users, by Christopher O'Brien.
- Add meanwhile-use-libtommath.patch: Use LibTomMath as an MPI
  instead of the bundled code (boo#1086826, deb#764494).
- Add meanwhile-fix-warnings.patch: Fix various warnings,
  including a find by Torrey McMahon (a function that is declared
  void but yet returns a value).
- Add meanwhile-fix-groupchat.patch: Fix for group chat crashes
  with IBM Notes version 8.5.1, by Jonathan Rice (pidgin#12637).
- Add meanwhile-fix-filetransfer.patch: Fix file transfers with
  recent Sametime servers, by Mikael Berthe.
- Add meanwhile-workaround-status-timestamp.patch: Fix Awareness
  status timestamps with recent Sametime clients, by Mikael Berthe.
- Disable mw_debug_mailme output.
- Move the Changelog file to the main package.
- Spec cleanup.
* Fri Sep 11 2015 mpluskal@suse.com
- Use url for source
- Update dependencies
- Cleanup spec file with spec-cleaner
* Mon Nov 28 2011 dimstar@opensuse.org
- Add meanwhile-glib-2.31.patch: Fix build with glib 2.31.
- Fix packaging: Do not package files in -doc and the library.
  + Move any files out of the lib package that do not belong there.
    This finally allows to have multiple libmeanwhil<n> installable
    without conflicting on file level.
* Wed Nov 23 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
- Employ shlib packaging
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Thu May 26 2011 crrodriguez@opensuse.org
- Remove "la" files and static libraries
- Disable doxygen docs generation, timestamps break build-compare.
* Thu May 14 2009 rfno@fietze-home.de
- apply patch to fix status update problem
  (http://sourceforge.net/tracker/index.php?func=detail&aid=1626349&group_id=110565&atid=656718)
* Thu May 10 2007 sbrabec@suse.cz
- Updated to version 1.0.2:
  * Encryption support.
  * Documentation package.
  * Large message support.
  * API changes, new library version.
  * Bug fixes.
* Fri Jan 27 2006 dmueller@suse.de
- update to 0.4.2 for Kopete support (#118081)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Sep 26 2005 mls@suse.de
- make devel package require base package
* Tue May 17 2005 adrian@suse.de
- update to version 0.4.1
* Tue Apr 26 2005 adrian@suse.de
- update to version 0.4.0
* Tue Dec  7 2004 adrian@suse.de
- initial package of version 0.3
